@@ -11,7 +11,7 @@ import DateTime
 
 sys.path.append(".")
 
-from locales_tools import \
+from itb_locales import \
     fetch_holidays, is_holiday, format_price
 
 days_and_holidays = {
