@@ -10,43 +10,68 @@ import random
 
 sys.path.append(".")
 
-from text_name_tools import \
-    and_list, leet, capitalize_name, sort_names, get_gender
+from itb_text_name import \
+    and_list, \
+    capitalize_name, \
+    get_gender, \
+    leet, \
+    sort_names
 
 names = {
     'Georg Pfolz': {
         'lowercase': 'georg pfolz',
-        'gender': 'male'
+        'capitalized': 'Georg Pfolz',
+        'gender': 'male',
+        'is_a_name': True
     },
     'Patrizia Höfstädter': {
         'lowercase': 'patrizia höfstädter',
-        'gender': 'female'
+        'capitalized': 'Patrizia Höfstädter',
+        'gender': 'female',
+        'is_a_name': True
     },
     'Eugénie Caraçon': {
         'lowercase': 'eugénie caraçon',
-        'gender': 'female'
+        'capitalized': 'Eugénie Caraçon',
+        'gender': 'female',
+        'is_a_name': True
     },
     'Joanna MacArthur': {
         'lowercase': 'joanna macarthur',
-        'gender': 'female'
+        'capitalized': 'Joanna MacArthur',
+        'gender': 'female',
+        'is_a_name': True
     },
     'Sandra de Vitt': {
         'lowercase': 'sandra de vitt',
-        'gender': 'female'
+        'capitalized': 'Sandra de Vitt',
+        'gender': 'female',
+        'is_a_name': True
     },
     'Roland Meier-Lansky': {
         'lowercase': 'roland meier-lansky',
-        'gender': 'male'
+        'capitalized': 'Roland Meier-Lansky',
+        'gender': 'male',
+        'is_a_name': True
     },
     'Bogumila Österreicher': {
         'lowercase': 'bogumila österreicher',
-        'gender': 'unknown'
+        'capitalized': 'Bogumila Österreicher',
+        'gender': 'unknown',
+        'is_a_name': True
+    },
+    'DsZHkfNijWFPrET JGLAjuaqZ': {
+        'lowercase': 'dszhkfnijwfpret jglajuaqz',
+        'capitalized': 'Dszhkfnijwfpret Jglajuaqz',
+        'gender': 'unknown',
+        'is_a_name': False
     }
 }
 
 names_sorted = [
     'Eugénie Caraçon',
     'Patrizia Höfstädter',
+    'DsZHkfNijWFPrET JGLAjuaqZ',
     'Joanna MacArthur',
     'Roland Meier-Lansky',
     'Bogumila Österreicher',
@@ -70,6 +95,7 @@ class TestTextName(unittest.TestCase):
         string_to_leet = random.choice(list(names))
         max_length = random.randint(6, 12)
         start_at_begin = random.randint(0, 1)
+        """
         print(f'{string_to_leet} --> {leet(string_to_leet)}')
         leeted_text = leet(
             text=string_to_leet,
@@ -79,13 +105,14 @@ class TestTextName(unittest.TestCase):
         print(
             f'{string_to_leet}, {max_length = }  {start_at_begin = } --> {leeted_text}'
         )
+        """
 
         # because of the use of random, using Asserts does not make any sense here
 
     def test_capitalize_name(self):
-        for name, name_dict in names.items():
+        for name_dict in names.values():
             capitalized_name = capitalize_name(text=name_dict.get('lowercase'))
-            self.assertEqual(name, capitalized_name)
+            self.assertEqual(name_dict.get('capitalized'), capitalized_name)
 
     def test_get_gender(self):
         for name, name_dict in names.items():
@@ -107,5 +134,3 @@ class TestTextName(unittest.TestCase):
 
 if __name__ == '__main__':
     unittest.main()
-
-    print('finished format tests.')
